@@ -1,6 +1,12 @@
-"Main interface for sso-oidc service type defs"
-from __future__ import annotations
+"""
+Main interface for sso-oidc service type definitions.
 
+Usage::
+
+    from mypy_boto3.sso_oidc.type_defs import ClientCreateTokenResponseTypeDef
+
+    data: ClientCreateTokenResponseTypeDef = {...}
+"""
 import sys
 
 if sys.version_info >= (3, 8):
@@ -9,14 +15,20 @@ else:
     from typing_extensions import TypedDict
 
 
-CreateTokenResponseTypeDef = TypedDict(
-    "CreateTokenResponseTypeDef",
+__all__ = (
+    "ClientCreateTokenResponseTypeDef",
+    "ClientRegisterClientResponseTypeDef",
+    "ClientStartDeviceAuthorizationResponseTypeDef",
+)
+
+ClientCreateTokenResponseTypeDef = TypedDict(
+    "ClientCreateTokenResponseTypeDef",
     {"accessToken": str, "tokenType": str, "expiresIn": int, "refreshToken": str, "idToken": str},
     total=False,
 )
 
-RegisterClientResponseTypeDef = TypedDict(
-    "RegisterClientResponseTypeDef",
+ClientRegisterClientResponseTypeDef = TypedDict(
+    "ClientRegisterClientResponseTypeDef",
     {
         "clientId": str,
         "clientSecret": str,
@@ -28,8 +40,8 @@ RegisterClientResponseTypeDef = TypedDict(
     total=False,
 )
 
-StartDeviceAuthorizationResponseTypeDef = TypedDict(
-    "StartDeviceAuthorizationResponseTypeDef",
+ClientStartDeviceAuthorizationResponseTypeDef = TypedDict(
+    "ClientStartDeviceAuthorizationResponseTypeDef",
     {
         "deviceCode": str,
         "userCode": str,
